# JuLime

`julime` is part of GeoLime ecosystem, not meant to stand alone use, checkout `geolime`.

Kept for backward compatibility -> move to `geolime_jl` instead.

Chek out latest information of DeepLime's work : <https://deeplime.io>
